pub struct TestOptions {
    pub patterns: PatternList,
    pub options: OptMap,
}
Options passed to all test cases

Fields

patterns: PatternList

List of regex patterns for test names to run Default is “.*”, to run all tests.

options: OptMap

additional test configuration, optional Keys may be test case names, or other keys meaningful for the test. Values are serialized json, with contents specific to the test