pub struct TestingSender<T: Transport> { /* private fields */ }Expand description
TestingSender sends messages to a Testing service Test api for testable actors and providers client for sending Testing messages
Implementations
sourceimpl<T: Transport> TestingSender<T>
impl<T: Transport> TestingSender<T>
pub fn set_timeout(&self, interval: Duration)
sourceimpl<'send> TestingSender<ProviderTransport<'send>>
impl<'send> TestingSender<ProviderTransport<'send>>
sourcepub fn for_actor(ld: &'send LinkDefinition) -> Self
pub fn for_actor(ld: &'send LinkDefinition) -> Self
Constructs a Sender using an actor’s LinkDefinition, Uses the provider’s HostBridge for rpc